pub struct TxRingMembersInfo {
pub rings: Rings,
pub decoy_info: Option<DecoyInfo>,
pub youngest_used_out_height: usize,
pub time_locked_outs: Vec<Timelock>,
}Expand description
Information on the outputs the transaction is referencing for inputs (ring members).
Fields
rings: Ringsdecoy_info: Option<DecoyInfo>Information on the structure of the decoys, must be None for txs before HardFork::V1
youngest_used_out_height: usizetime_locked_outs: Vec<Timelock>Trait Implementations