pub struct DecoyInfo {
pub mixable: usize,
pub not_mixable: usize,
pub min_decoys: usize,
pub max_decoys: usize,
}Expand description
A struct holding information about the inputs and their decoys. This data can vary by block so this data needs to be retrieved after every change in the blockchain.
This data does not need to be refreshed if one of these are true:
- The input amounts are ALL 0 (RCT)
- The top block hash is the same as when this data was retrieved (the blockchain state is unchanged).
https://cuprate.github.io/monero-book/consensus_rules/transactions/decoys.html
Fields
mixable: usizeThe number of inputs that have enough outputs on the chain to mix with.
not_mixable: usizeThe number of inputs that don’t have enough outputs on the chain to mix with.
min_decoys: usizeThe minimum amount of decoys used in the transaction.
max_decoys: usizeThe maximum amount of decoys used in the transaction.
Implementations
Sourceimpl DecoyInfo
impl DecoyInfo
Sourcepub fn new(
inputs: &[Input],
outputs_with_amount: impl Fn(u64) -> usize,
hf: HardFork,
) -> Result<Self, TransactionError>
pub fn new( inputs: &[Input], outputs_with_amount: impl Fn(u64) -> usize, hf: HardFork, ) -> Result<Self, TransactionError>
Creates a new DecoyInfo struct relating to the passed in inputs, This is only needed from
hf 2 onwards.
outputs_with_amount is a list of the amount of outputs currently on the chain with the same amount
as the inputs amount at the same index. For RCT inputs it instead should be None.
So:
amount_outs_on_chain(inputs[X]) == outputs_with_amount[X]
Do not rely on this function to do consensus checks!